@@ -131,10 +131,10 @@ namespace Aws
              * @param pkeyPath path to the private key (pem file) to use
              * @param allocator memory allocator to use
              *
-             * @return Mqtt5ClientBuilder
+             * @return std::shared_ptr of Mqtt5ClientBuilder.
              */
-            static Mqtt5ClientBuilder *NewMqtt5ClientBuilderWithMtlsFromPath(
-                const Crt::String hostName,
+            static std::shared_ptr<Mqtt5ClientBuilder> CreateMqtt5ClientBuilderWithMtlsFromPath(
+                const Crt::String &hostName,
                 const char *certPath,
                 const char *pkeyPath,
                 Crt::Allocator *allocator = Crt::ApiAllocator()) noexcept;
@@ -144,16 +144,16 @@ namespace Aws
              * format.
              *
              * @param hostName - AWS IoT endpoint to connect to
-             * @param certPath buffer containing the X509 certificate in a PEM format
-             * @param pkeyPath buffer containing the private key in a PEM format
+             * @param cert buffer containing the X509 certificate in a PEM format
+             * @param pkey buffer containing the private key in a PEM format
              * @param allocator memory allocator to use
              *
-             * @return Mqtt5ClientBuilder
+             * @return std::shared_ptr of Mqtt5ClientBuilder.
              */
-            static Mqtt5ClientBuilder *NewMqtt5ClientBuilderWithMtlsFromMemory(
-                const Crt::String hostName,
-                const Crt::ByteCursor &certPath,
-                const Crt::ByteCursor &pkeyPath,
+            static std::shared_ptr<Mqtt5ClientBuilder> CreateMqtt5ClientBuilderWithMtlsFromMemory(
+                const Crt::String &hostName,
+                const Crt::ByteCursor &cert,
+                const Crt::ByteCursor &pkey,
                 Crt::Allocator *allocator = Crt::ApiAllocator()) noexcept;
 
             /**
@@ -165,10 +165,10 @@ namespace Aws
              * @param pkcs11Options PKCS#11 options
              * @param allocator memory allocator to use
              *
-             * @return Mqtt5ClientBuilder
+             * @return std::shared_ptr of Mqtt5ClientBuilder.
              */
-            static Mqtt5ClientBuilder *NewMqtt5ClientBuilderWithMtlsPkcs11(
-                const Crt::String hostName,
+            static std::shared_ptr<Mqtt5ClientBuilder> CreateMqtt5ClientBuilderWithMtlsPkcs11(
+                const Crt::String &hostName,
                 const Crt::Io::TlsContextPkcs11Options &pkcs11Options,
                 Crt::Allocator *allocator = Crt::ApiAllocator()) noexcept;
 
@@ -181,10 +181,10 @@ namespace Aws
              * @param options The PKCS12 options to use.
              * @param allocator - memory allocator to use
              *
-             * @return Mqtt5ClientBuilder
+             * @return std::shared_ptr of Mqtt5ClientBuilder.
              */
-            static Mqtt5ClientBuilder *NewMqtt5ClientBuilderWithMtlsPkcs12(
-                const Crt::String hostName,
+            static std::shared_ptr<Mqtt5ClientBuilder> CreateMqtt5ClientBuilderWithMtlsPkcs12(
+                const Crt::String &hostName,
                 const struct Pkcs12Options &options,
                 Crt::Allocator *allocator = Crt::ApiAllocator()) noexcept;
 
@@ -199,10 +199,10 @@ namespace Aws
              *    Example: `CurrentUser\MY\A11F8A9B5DF5B98BA3508FBCA575D09570E0D2C6`
              * @param allocator memory allocator to use
              *
-             * @return Mqtt5ClientBuilder
+             * @return std::shared_ptr of Mqtt5ClientBuilder.
              */
-            static Mqtt5ClientBuilder *NewMqtt5ClientBuilderWithWindowsCertStorePath(
-                const Crt::String hostName,
+            static std::shared_ptr<Mqtt5ClientBuilder> CreateMqtt5ClientBuilderWithWindowsCertStorePath(
+                const Crt::String &hostName,
                 const char *windowsCertStorePath,
                 Crt::Allocator *allocator = Crt::ApiAllocator()) noexcept;
 
@@ -213,10 +213,10 @@ namespace Aws
              * @param config websocket configuration information
              * @param allocator memory allocator to use
              *
-             * Mqtt5ClientBuilder
+             * @return std::shared_ptr of Mqtt5ClientBuilder.
              */
-            static Mqtt5ClientBuilder *NewMqtt5ClientBuilderWithWebsocket(
-                const Crt::String hostName,
+            static std::shared_ptr<Mqtt5ClientBuilder> CreateMqtt5ClientBuilderWithWebsocket(
+                const Crt::String &hostName,
                 const WebsocketConfig &config,
                 Crt::Allocator *allocator = Crt::ApiAllocator()) noexcept;
 
@@ -227,10 +227,10 @@ namespace Aws
              * @param customAuthConfig custom authorization configuration information
              * @param allocator memory allocator to use
              *
-             * Mqtt5ClientBuilder
+             * @return std::shared_ptr of Mqtt5ClientBuilder.
              */
-            static Mqtt5ClientBuilder *NewMqtt5ClientBuilderWithCustomAuthorizer(
-                const Crt::String hostName,
+            static std::shared_ptr<Mqtt5ClientBuilder> CreateMqtt5ClientBuilderWithCustomAuthorizer(
+                const Crt::String &hostName,
                 const Mqtt5CustomAuthConfig &customAuthConfig,
                 Crt::Allocator *allocator) noexcept;
 
@@ -242,10 +242,10 @@ namespace Aws
              * @param config websocket configuration information
              * @param allocator memory allocator to use
              *
-             * Mqtt5ClientBuilder
+             * @return std::shared_ptr of Mqtt5ClientBuilder.
              */
-            static Mqtt5ClientBuilder *NewMqtt5ClientBuilderWithCustomAuthorizerWebsocket(
-                const Crt::String hostName,
+            static std::shared_ptr<Mqtt5ClientBuilder> CreateMqtt5ClientBuilderWithCustomAuthorizerWebsocket(
+                const Crt::String &hostName,
                 const Mqtt5CustomAuthConfig &customAuthConfig,
                 const WebsocketConfig &config,
                 Crt::Allocator *allocator) noexcept;
@@ -298,6 +298,18 @@ namespace Aws
              */
             Mqtt5ClientBuilder &WithCertificateAuthority(const Crt::ByteCursor &cert) noexcept;
 
+            /**
+             * Sets the tls cipher preference for the tls context options.
+             *
+             * @param cipherPref the tls cipher preference to use for the tls context options.
+             * Warning: Setting a custom security policy is supported only on Unix-like platforms (e.g., Linux, Android)
+             * when using the s2n library. Other platforms currently support only
+             * `AWS_IO_TLS_CIPHER_PREF_SYSTEM_DEFAULT`.
+             *
+             * @return this builder object
+             */
+            Mqtt5ClientBuilder &WithTlsCipherPreference(aws_tls_cipher_pref cipherPref) noexcept;
+
             /**
              * Overrides the socket properties of the underlying MQTT connections made by the client.  Leave undefined
              * to use defaults (no TCP keep alive, 10 second socket timeout).
@@ -540,12 +552,85 @@ namespace Aws
              */
             Mqtt5ClientBuilder &WithPublishReceivedCallback(OnPublishReceivedHandler callback) noexcept;
 
+            /**
+             * @deprecated Use Mqtt5ClientBuilder::CreateMqtt5ClientBuilderWithMtlsFromPath instead.
+             */
+            static Mqtt5ClientBuilder *NewMqtt5ClientBuilderWithMtlsFromPath(
+                const Crt::String hostName,
+                const char *certPath,
+                const char *pkeyPath,
+                Crt::Allocator *allocator = Crt::ApiAllocator()) noexcept;
+
+            /**
+             * @deprecated Use Mqtt5ClientBuilder::CreateMqtt5ClientBuilderWithMtlsFromMemory instead.
+             */
+            static Mqtt5ClientBuilder *NewMqtt5ClientBuilderWithMtlsFromMemory(
+                const Crt::String hostName,
+                const Crt::ByteCursor &cert,
+                const Crt::ByteCursor &pkey,
+                Crt::Allocator *allocator = Crt::ApiAllocator()) noexcept;
+
+            /**
+             * @deprecated Use Mqtt5ClientBuilder::CreateMqtt5ClientBuilderWithMtlsPkcs11 instead.
+             */
+            static Mqtt5ClientBuilder *NewMqtt5ClientBuilderWithMtlsPkcs11(
+                const Crt::String hostName,
+                const Crt::Io::TlsContextPkcs11Options &pkcs11Options,
+                Crt::Allocator *allocator = Crt::ApiAllocator()) noexcept;
+
+            /**
+             * @deprecated Use Mqtt5ClientBuilder::CreateMqtt5ClientBuilderWithMtlsPkcs12 instead.
+             */
+            static Mqtt5ClientBuilder *NewMqtt5ClientBuilderWithMtlsPkcs12(
+                const Crt::String hostName,
+                const struct Pkcs12Options &options,
+                Crt::Allocator *allocator = Crt::ApiAllocator()) noexcept;
+
+            /**
+             * @deprecated Use Mqtt5ClientBuilder::CreateMqtt5ClientBuilderWithWindowsCertStorePath instead.
+             */
+            static Mqtt5ClientBuilder *NewMqtt5ClientBuilderWithWindowsCertStorePath(
+                const Crt::String hostName,
+                const char *windowsCertStorePath,
+                Crt::Allocator *allocator = Crt::ApiAllocator()) noexcept;
+
+            /**
+             * @deprecated Use Mqtt5ClientBuilder::CreateMqtt5ClientBuilderWithWebsocket instead.
+             */
+            static Mqtt5ClientBuilder *NewMqtt5ClientBuilderWithWebsocket(
+                const Crt::String hostName,
+                const WebsocketConfig &config,
+                Crt::Allocator *allocator = Crt::ApiAllocator()) noexcept;
+
+            /**
+             * @deprecated Use Mqtt5ClientBuilder::CreateMqtt5ClientBuilderWithCustomAuthorizer instead.
+             */
+            static Mqtt5ClientBuilder *NewMqtt5ClientBuilderWithCustomAuthorizer(
+                const Crt::String hostName,
+                const Mqtt5CustomAuthConfig &customAuthConfig,
+                Crt::Allocator *allocator) noexcept;
+
+            /**
+             * @deprecated Use Mqtt5ClientBuilder::CreateMqtt5ClientBuilderWithCustomAuthorizerWebsocket instead.
+             */
+            static Mqtt5ClientBuilder *NewMqtt5ClientBuilderWithCustomAuthorizerWebsocket(
+                const Crt::String hostName,
+                const Mqtt5CustomAuthConfig &customAuthConfig,
+                const WebsocketConfig &config,
+                Crt::Allocator *allocator) noexcept;
+
           private:
             // Common setup shared by all valid constructors
             Mqtt5ClientBuilder(Crt::Allocator *allocator) noexcept;
             // Common setup shared by all valid constructors
             Mqtt5ClientBuilder(int error, Crt::Allocator *allocator) noexcept;
 
+            /*
+             * Creates a new Mqtt5ClientBuilder instance with default values.
+             */
+            static std::shared_ptr<Mqtt5ClientBuilder> CreateMqtt5ClientBuilder(
+                Crt::Allocator *allocator = Crt::ApiAllocator()) noexcept;
+
             Crt::Allocator *m_allocator;
 
             /**
